// $Id: syntaxinfo-test.c,v 1.1 2003/11/04 22:32:40 ensc Exp $    --*- c -*--

// Copyright (C) 2003 Enrico Scholz <enrico.scholz@informatik.tu-chemnitz.de>
//  
// This program is free software; you can redistribute it and/or modify
// it under the terms of the GNU General Public License as published by
// the Free Software Foundation; version 2 of the License.
//  
// This program is distributed in the hope that it will be useful,
// but WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
// GNU General Public License for more details.
//  
// You should have received a copy of the GNU General Public License
// along with this program; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.


#ifdef HAVE_CONFIG_H
#  include <config.h>
#endif

#include "syntaxinfo.h"
#include "wrappers.h"
#include "util.h"
#include "util-io.h"

int	wrapper_exit_code = 1;

int main(int argc, char *argv[])
{
  if (argc!=2) {
    WRITE_MSG(2, "Usage: syntaxinfo-test <FILE>\n");
    return EXIT_FAILURE;
  }

  int		fd  = Eopen(argv[1], O_RDONLY,0);
  size_t	len = Elseek(fd, 0, SEEK_END);
  char		buf[len+1];

  Elseek(fd, 0, SEEK_SET);
  Eread(fd, buf, len);
  buf[len] = '\0';

  struct SyntaxInfo	info;
  char *		ptr = buf;

  while (*ptr!=0) {
    char const		*org_ptr = ptr;
    
    if (!SyntaxInfo_init(&info, const_cast(char const **)(&ptr))) {
      WRITE_MSG(2, "Failed to parse '");
      (void)write(2, org_ptr, ptr-org_ptr+1);
      WRITE_MSG(2, "'\n");
      ++ptr;
    }
    else {
      switch (info.type) {
	case synVSERVER	:  WRITE_MSG(1, "v"); /*@fallthrough@*/
	case synSET	:
	{
	  size_t	i;
	  char const *	delim=0;

	  WRITE_MSG(1, "[");
	  for (i=0; i<info.info.set.l; ++i) {
	    if (delim!=0) WRITE_STR(1, delim);
	    WRITE_STR(1, info.info.set.v[i]);
	    delim = ",";
	  }
	  WRITE_MSG(1, "]\n");

	  break;
	}

	case synINT	:  WRITE_MSG(1, "i\n"); break;
	case synUINT	:  WRITE_MSG(1, "u\n"); break;
	case synSTRING	:  WRITE_MSG(1, "s\n"); break;
	case synPATH	:  WRITE_MSG(1, "p\n"); break;
	default		:  WRITE_MSG(1, "?\n"); break;
      }

      SyntaxInfo_destroy(&info);
    }
  }
}
